package com.hp.user.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.alibaba.nacos.client.naming.utils.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.hp.user.client.entity.CertificateVO;
import com.hp.user.client.entity.ElectricianVO;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.ElectricianService;
import com.hp.user.service.dao.CertificateMapper;
import com.hp.user.service.dao.ElectricianMapper;
import com.hp.user.service.entity.Certificate;
import com.hp.user.service.entity.Electrician;

@Service
public class ElectricianServiceImpl implements ElectricianService{
	
	@Autowired
	private ElectricianMapper electricianMapper;
	
	@Autowired
	private CertificateMapper certificateMapper;

	@Override
	@Transactional
	public Result createElectrician(ElectricianVO electricianVO) {
		Result result = new Result();
		try {
			String phone = electricianVO.getPhone();
			String name = electricianVO.getName();
			
			if(StringUtils.isBlank(phone)) {
				result.setCode("-1");
				result.setMessage("手机号不能为空！");
				return result;
			}
			if(StringUtils.isBlank(name)) {
				result.setCode("-1");
				result.setMessage("姓名能为空！");
				return result;
			}
			Electrician electrician = new Electrician();
			BeanUtils.copyProperties(electricianVO, electrician);
			String electricianId = IdWorker.getIdStr();
			electrician.setElectricianId(electricianId);
			electricianMapper.insert(electrician);
			List<CertificateVO> list = electricianVO.getCertificateList();
			if(!CollectionUtils.isEmpty(list)) {
				Certificate certificate;
				List<Certificate> newList = new ArrayList<>();
				for(CertificateVO certificateVO : list) {
					certificate = new Certificate();
					BeanUtils.copyProperties(certificateVO, certificate);
					certificate.setCertificateId(IdWorker.getIdStr());
					certificate.setElectricianId(electricianId);
					newList.add(certificate);
				}
				certificateMapper.batchInsertCertificate(newList);
			}
		}catch(Exception e) {
			result.setCode("-1");
			result.setMessage("系统内部错误");
			throw e;
		}
		// TODO Auto-generated method stub
		return result;
	}

}
